@@ -43,7 +43,6 @@ import getpass
 import signal
 import ctypes
 import string
-import glob
 
 try:
     import requests
@@ -115,7 +114,7 @@ except NameError:
     DEAD_ENGINE_ERRORS = (EOFError, IOError)
 
 
-__version__ = "1.15.52"
+__version__ = "1.16.8"
 
 __author__ = "Bajusz Tamás"
 __email__ = "gbtami@gmail.com"
@@ -138,6 +137,37 @@ LVL_SKILL = [-4, 0, 3, 6, 10, 14, 16, 18, 20]
 LVL_MOVETIMES = [50, 50, 100, 150, 200, 300, 400, 500, 1000]
 LVL_DEPTHS = [1, 1, 1, 2, 3, 5, 8, 13, 22]
 
+NNUE_NET = {
+    "asean": "88c4f9118f34",
+    "atomic": "4ecb2067c716",
+    "capablanca": "e605d6d3dd31",
+    "chak": "0dfa519b8ee7",
+    "crazyhouse": "f0782c10a2d4",
+    "empire": "d14c0d04359e",
+    "grand": "596776a80f03",
+    "janggi": "ffbf1d95cea2",
+    "makpong": "75299b96ab1d",
+    "makruk": "e14ecd7ae145",
+    "minishogi": "32efe2ac350b",
+    "nn": "46832cfbead3",
+    "orda": "af8fab8f210b",
+    "ordamirror": "b432a42e3738",
+    "seirawan": "d6ec9a356fa8",
+    "shinobi": "4abe32d99161",
+    "shogi": "878ca61334a7",
+    "shogun": "04b4fe4bbad7",
+    "sittuyin": "3c3ed74dbe54",
+    "synochess": "42aaabb0581f",
+    "torishogi": "0c3670e88a63",
+    "xiangqi": "28d6221e2440",
+}
+
+NNUE_ALIAS = {
+    "cambodian": "makruk",
+    "chess": "nn",
+    "placement": "nn",
+}
+
 
 def intro():
     return r"""
@@ -550,9 +580,11 @@ def set_variant_options(p, variant, chess960):
 
     setoption(p, "UCI_Chess960", chess960)
 
-    eval_file = variant + ".nnue"
-    if os.path.isfile(eval_file):
-        setoption(p, "EvalFile", eval_file)
+    if variant in NNUE_NET or variant in NNUE_ALIAS:
+        vari = NNUE_ALIAS[variant] if variant in NNUE_ALIAS else variant
+        eval_file = "%s-%s.nnue" % (vari, NNUE_NET[vari])
+        if os.path.isfile(eval_file):
+            setoption(p, "EvalFile", eval_file)
 
     if variant in ["standard", "fromposition", "chess960"]:
         setoption(p, "UCI_Variant", "chess")
@@ -779,7 +811,6 @@ class Worker(threading.Thread):
         self.stockfish_info["options"] = {}
         self.stockfish_info["options"]["threads"] = str(self.threads)
         self.stockfish_info["options"]["hash"] = str(self.memory)
-        self.stockfish_info["options"]["analysis contempt"] = "Off"
 
         # Custom options
         if self.conf.has_section("Stockfish"):
@@ -787,7 +818,7 @@ class Worker(threading.Thread):
                 self.stockfish_info["options"][name] = value
 
         # Add .nnue file list
-        self.stockfish_info["nnue"] = glob.glob("*.nnue")
+        self.stockfish_info["nnue"] = ["%s-%s.nnue" % (v, NNUE_NET[v]) for v in NNUE_NET]
 
         # Set UCI options
         for name, value in self.stockfish_info["options"].items():
@@ -1053,16 +1084,13 @@ def download_github_release(conf, release_page, filename):
 
             if sys.stderr.isatty():
                 sys.stderr.write("\rDownloading %s: %d/%d (%d%%)" % (
-                                    filename, progress, size,
-                                    progress * 100 / size))
+                    filename, progress, size,
+                    progress * 100 / size))
                 sys.stderr.flush()
     if sys.stderr.isatty():
         sys.stderr.write("\n")
         sys.stderr.flush()
 
-    if filename.endswith(".nnue"):
-        return filename
-
     # Make executable
     logging.info("chmod +x %s", filename)
     st = os.stat(path)
@@ -1346,7 +1374,13 @@ def validate_stockfish_command(stockfish_command, conf):
 
     logging.debug("Supported variants: %s", ", ".join(variants))
 
-    required_variants = set(["chess", "crazyhouse", "placement", "makruk", "sittuyin", "cambodian", "shogi", "minishogi", "kyotoshogi", "capablanca", "capahouse", "seirawan", "shouse", "grand", "grandhouse", "gothic", "gothhouse", "xiangqi", "minixiangqi", "shogun", "janggi", "makpong", "orda", "synochess", "shinobi", "empire", "ordamirror"])
+    required_variants = set([
+        "chess", "crazyhouse", "placement", "makruk", "sittuyin", "cambodian",
+        "shogi", "minishogi", "kyotoshogi", "capablanca", "capahouse",
+        "seirawan", "shouse", "grand", "grandhouse", "gothic", "gothhouse",
+        "xiangqi", "minixiangqi", "shogun", "janggi", "makpong", "orda",
+        "synochess", "shinobi", "empire", "ordamirror", "torishogi",
+        "gorogoroplus", "chak", "chennis"])
     missing_variants = required_variants.difference(variants)
     if missing_variants:
         raise ConfigError("Ensure you are using pychess custom Fairy-Stockfish. "
@@ -1371,6 +1405,14 @@ def parse_bool(inp, default=False):
         raise ConfigError("Not a boolean value: %s", inp)
 
 
+def validate_nnue():
+    nnue_link = "https://github.com/ianfab/Fairy-Stockfish/wiki/List-of-networks"
+    for variant in NNUE_NET:
+        nnue_file = "%s-%s.nnue" % (variant, NNUE_NET[variant])
+        if not os.path.isfile(nnue_file):
+            raise ConfigError("Missing nnue file: %s\nDownload it from %s" % (nnue_file, nnue_link))
+
+
 def validate_cores(cores):
     if not cores or cores.strip().lower() == "auto":
         return max(1, multiprocessing.cpu_count() - 1)
@@ -1555,8 +1597,8 @@ def cmd_run(args):
         print()
         stockfish_command = get_stockfish_command(conf)
 
-    # Check .nnue updates (only for shogi at this moment)
-    download_github_release(conf, STOCKFISH_RELEASES, "shogi.nnue")
+    # Check .nnue files
+    validate_nnue()
 
     print()
     print("### Checking configuration ...")
@@ -1600,7 +1642,7 @@ def cmd_run(args):
         buckets[i % instances] += 1
 
     progress_reporter = ProgressReporter(len(buckets) + 4, conf)
-    progress_reporter.setDaemon(True)
+    progress_reporter.daemon = True
     progress_reporter.start()
 
     workers = [Worker(conf, bucket, memory // instances, progress_reporter) for bucket in buckets]
@@ -1608,7 +1650,7 @@ def cmd_run(args):
     # Start all threads
     for i, worker in enumerate(workers):
         worker.set_name("><> %d" % (i + 1))
-        worker.setDaemon(True)
+        worker.daemon = True
         worker.start()
 
     # Wait while the workers are running
@@ -2006,6 +2048,7 @@ promotionPieceTypes = -
 promotedPieceType = p:c m:b h:n l:r
 mandatoryPiecePromotion = true
 stalemateValue = loss
+nFoldRule = 4
 perpetualCheckIllegal = true
 startFen = rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/LH1CK1HL[LHMMDJ] w kq - 0 1
 capturesToHand = false
@@ -2042,6 +2085,71 @@ flagPiece = k
 whiteFlag = *8
 blackFlag = *1
 flyingGeneral = true
+
+[gorogoroplus:gorogoro]
+startFen = sgkgs/5/1ppp1/1PPP1/5/SGKGS[LNln] w 0 1
+lance = l
+shogiKnight = n
+promotedPieceType = l:g n:g
+
+[chak]
+maxRank = 9
+maxFile = 9
+rook = r
+knight = v
+centaur = j
+immobile = o
+customPiece1 = s:FvW
+customPiece2 = q:pQ
+customPiece3 = d:mQ2cQ2
+customPiece4 = p:fsmWfceF
+customPiece5 = k:WF
+customPiece6 = w:FvW
+startFen = rvsqkjsvr/4o4/p1p1p1p1p/9/9/9/P1P1P1P1P/4O4/RVSJKQSVR w - - 0 1
+mobilityRegionWhiteCustomPiece6 = *5 *6 *7 *8 *9
+mobilityRegionWhiteCustomPiece3 = *5 *6 *7 *8 *9
+mobilityRegionBlackCustomPiece6 = *1 *2 *3 *4 *5
+mobilityRegionBlackCustomPiece3 = *1 *2 *3 *4 *5
+promotionRank = 5
+promotionPieceTypes = -
+mandatoryPiecePromotion = true
+promotedPieceType = p:w k:d
+extinctionValue = loss
+extinctionPieceTypes = kd
+extinctionPseudoRoyal = true
+flagPiece = d
+whiteFlag = e8
+blackFlag = e2
+nMoveRule = 50
+nFoldRule = 3
+nFoldValue = draw
+stalemateValue = win
+
+[chennis]
+maxRank = 7
+maxFile = 7
+mobilityRegionWhiteKing = b1 c1 d1 e1 f1 b2 c2 d2 e2 f2 b3 c3 d3 e3 f3 b4 c4 d4 e4 f4
+mobilityRegionBlackKing = b4 c4 d4 e4 f4 b5 c5 d5 e5 f5 b6 c6 d6 e6 f6 b7 c7 d7 e7 f7
+customPiece1 = p:fmWfceF
+cannon = c
+commoner = m
+fers = f
+soldier = s
+king = k
+bishop = b
+knight = n
+rook = r
+promotionPieceTypes = -
+promotedPieceType = p:r f:c s:b m:n
+promotionRank = 1
+startFen = 1fkm3/1p1s3/7/7/7/3S1P1/3MKF1[] w - 0 1
+pieceDrops = true
+capturesToHand = true
+pieceDemotion = true
+mandatoryPiecePromotion = true
+dropPromoted = true
+castling = false
+stalemateValue = loss
 """)
 
     ini_file = os.path.join(engine_dir, "variants.ini")
